import datetime


dt_now = datetime.datetime.now()
__title__ = 'iinfer (Visual Prediction Application)'
__version__ = '0.4.9'
__copyright__ = f'Copyright (c) {dt_now.strftime("%Y")} hamacom2004jp <https://github.com/hamacom2004jp/iinfer>'

__all__ = ['__version__']